#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ini
version:              0.4.2
visibility:           public
id:                   ini-0.4.2-4SR6UoTl5aS2jRW8qlQlz7
key:                  ini-0.4.2-4SR6UoTl5aS2jRW8qlQlz7
license:              BSD-3-Clause
copyright:            2013 Chris Done
maintainer:           Andreas Abel
author:               Chris Done
homepage:             https://github.com/andreasabel/ini
synopsis:             Configuration files in the INI format.
description:          Quick and easy configuration files in the INI format.
category:             Data, Configuration
abi:                  9f119f255edeb610183ccd7bfc55d491
exposed:              True
exposed-modules:      Data.Ini
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ini-0.4.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ini
hs-libraries:         HSini-0.4.2-4SR6UoTl5aS2jRW8qlQlz7
depends:
    attoparsec-0.14.4-5ZTCKiuMNMIGB4CMz6Pozo base-4.18.2.1 text-2.0.2
    unordered-containers-0.2.20.1-F8uKhGV3AlWbjcYkQjkcw

haddock-interfaces:   /usr/share/doc/haskell-ini/html/ini.haddock
haddock-html:         /usr/share/doc/haskell-ini/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

